@@ -289,7 +289,7 @@ const PreviewView = new Lang.Class({
             uri = this._uriRewrite(uri);
 
         try {
-            Gio.AppInfo.launch_default_for_uri(uri, context)
+            Gio.AppInfo.launch_default_for_uri(uri, context);
         } catch (e) {
             log('Unable to open external link: ' + e.message);
         }
@@ -580,6 +580,10 @@ const PreviewNavBar = new Lang.Class({
         this.widget.document_model = model;
         if (!model)
             this.hide();
+
+        let hasMultiplePages = (model.document.get_n_pages() > 1);
+        Application.application.lookup_action('bookmark-page').enabled = hasMultiplePages;
+        Application.application.lookup_action('places').enabled = hasMultiplePages;
     },
 
     show: function() {
@@ -765,7 +769,7 @@ const PreviewNavButtons = new Lang.Class({
         this._visible = false;
         this._fadeOutButton(this.prev_widget);
         this._fadeOutButton(this.next_widget);
-    },
+    }
 });
 
 const PreviewToolbar = new Lang.Class({
@@ -781,12 +785,7 @@ const PreviewToolbar = new Lang.Class({
         this._gearMenu = Application.application.lookup_action('gear-menu');
 
         // back button, on the left of the toolbar
-        let iconName =
-            (this.toolbar.get_direction() == Gtk.TextDirection.RTL) ?
-            'go-next-symbolic' : 'go-previous-symbolic';
-        let backButton = new Gd.HeaderSimpleButton({ symbolic_icon_name: iconName,
-                                                     label: _("Back") });
-        this.toolbar.pack_start(backButton);
+        let backButton = this.addBackButton();
         backButton.connect('clicked', Lang.bind(this,
             function() {
                 Application.documentManager.setActiveItem(null);
